.. kyber-py documentation master file, created by
   sphinx-quickstart on Fri Jul 19 18:19:51 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to kyber-py's documentation!
====================================

Welcome to the documentation of the kyber-py package.
This is a pure-python implementation of th  ML-KEM (formely Kyber) algorithm
for cryptographic exchange of keys.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
